@@ -125,15 +125,8 @@ struct data_t {
 
 static void help(void)
 {
-	struct ts_lib_version_data *ver = ts_libversion();
-
-	printf("                 _       _ _ _\n");
-	printf("                | |_ ___| (_) |__\n");
-	printf("                | __/ __| | | '_ \\\n");
-	printf("                | |_\\__ \\ | | |_) |\n");
-	printf("                 \\__|___/_|_|_.__/\n\n");
-	printf("tslib %s / libts ABI version %d (0x%06X)\n",
-		ver->package_version, ver->version_num >> 16, ver->version_num);
+	ts_print_ascii_logo(16);
+	printf("%s", tslib_version());
 	printf("\n");
 	printf("Starts tslib instance listening to given event <device>, creates a virtual\n");
 	printf("input event device with given <name> using 'uinput', then continually reads\n");
@@ -158,8 +151,7 @@ static void help(void)
 static int send_touch_events(struct data_t *data, struct ts_sample_mt **s,
 			     int nr, int max_slots)
 {
-	int i;
-	int j;
+	int i, j, k;
 	int c = 0;
 
 	for (j = 0; j < nr; j++) {
@@ -319,12 +311,12 @@ static int send_touch_events(struct data_t *data, struct ts_sample_mt **s,
 			data->ev[c].code = SYN_REPORT;
 			data->ev[c].value = 0;
 
-
-			if (write(data->fd_uinput,
-				  data->ev,
-				  sizeof(struct input_event) * (c + 1)) < 0) {
-				perror("write");
-				return errno;
+			for(k = 0; k <= c; k++) {
+				if (write(data->fd_uinput, &data->ev[k],
+					  sizeof(struct input_event)) == -1) {
+					perror("write");
+					return errno;
+				}
 			}
 		}
 
@@ -895,7 +887,8 @@ int main(int argc, char **argv)
 		}
 	#else
 		fprintf(stderr, DEFAULT_UINPUT_NAME
-		": See the kernel log for the device number\n");
+			": kernel with uinput version < 4 is not supported\n");
+		goto out;
 	#endif
 		if (daemon(0, 0) == -1) {
 			perror("error starting daemon");
